summaryrefslogtreecommitdiffstats
path: root/kmymoney2/views/kinvestmentview.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/views/kinvestmentview.cpp')
-rw-r--r--kmymoney2/views/kinvestmentview.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kmymoney2/views/kinvestmentview.cpp b/kmymoney2/views/kinvestmentview.cpp
index 7fe7500..ba1876f 100644
--- a/kmymoney2/views/kinvestmentview.cpp
+++ b/kmymoney2/views/kinvestmentview.cpp
@@ -62,8 +62,8 @@ public:
-KInvestmentView::KInvestmentView(TQWidget *tqparent, const char *name) :
- KInvestmentViewDecl(tqparent,name),
+KInvestmentView::KInvestmentView(TQWidget *parent, const char *name) :
+ KInvestmentViewDecl(parent,name),
d(new Private)
{
m_table->setRootIsDecorated(false);
@@ -215,7 +215,7 @@ bool KInvestmentView::slotSelectAccount(const TQString& id, const TQString& tran
try {
d->m_account = MyMoneyFile::instance()->account(id);
// if a stock account is selected, we show the
// the corresponding tqparent (investment) account
if(d->m_account.isInvest()) {
d->m_account = MyMoneyFile::instance()->account(d->m_account.parentAccountId());
}
@@ -215,7 +215,7 @@ bool KInvestmentView::slotSelectAccount(const TQString& id, const TQString& tran
d->m_account = MyMoneyFile::instance()->account(id);
// if a stock account is selected, we show the
- // the corresponding tqparent (investment) account
+ // the corresponding parent (investment) account
if(d->m_account.isInvest()) {
d->m_account = MyMoneyFile::instance()->account(d->m_account.parentAccountId());